@@ -14,11 +14,11 @@ RPM::Packager - Manifest-based approach for building RPMs
 
 =head1 VERSION
 
-Version 0.0.10
+Version 0.1.0
 
 =cut
 
-our $VERSION = 'v0.0.10';
+our $VERSION = 'v0.1.0';
 
 =head1 SYNOPSIS
 
@@ -41,6 +41,7 @@ simple as writing a YAML file that looks like the following:
     sign:                               # optionally, gpg signing of RPM
       gpg_name: ED16CAB                 # provide the GPG key ID
       passphrase_cmd: cat secret_file   # command to retrieve the secret
+    after_install: /path/to/script      # script to run after the package is installed (%post)
 
 Then run:
 
@@ -69,7 +70,8 @@ You may also interact with the library directly as long as you pass in the manif
         sign    => {
             'gpg_name' => 'ED16CAB',
             'passphrase_cmd' => 'cat secret_file'
-        }
+        },
+        after_install => 'foo/bar/baz.sh'
     );
 
     my $obj = RPM::Packager->new(%args);
@@ -152,6 +154,15 @@ sub add_gpg_opts {
     $self->{gpg_passphrase} = RPM::Packager::Utils::eval_command($passphrase_cmd);
 }
 
+sub add_after_install {
+    my $self = shift;
+    return unless ( $self->{after_install} );
+
+    my $opts = $self->{opts} || [];
+    push @{$opts}, '--after-install', $self->{after_install};
+    $self->{opts} = $opts;
+}
+
 sub populate_opts {
     my $self            = shift;
     my $version         = $self->find_version();
@@ -169,6 +180,7 @@ sub populate_opts {
 
     $self->{opts} = [@opts];
     $self->add_gpg_opts();
+    $self->add_after_install();
     push @{ $self->{opts} }, '.';    # relative to the temporary directory
 }
 
